@@ -212,7 +212,7 @@ class IPKernelApp(BaseIPythonApplication, InteractiveShellApp, ConnectionFileMix
             self.poller = ParentPollerUnix()
 
     def _try_bind_socket(self, s, port):
-        iface = "%s://%s" % (self.transport, self.ip)
+        iface = f"{self.transport}://{self.ip}"
         if self.transport == "tcp":
             if port <= 0:
                 port = s.bind_to_random_port(iface)
@@ -465,7 +465,7 @@ class IPKernelApp(BaseIPythonApplication, InteractiveShellApp, ConnectionFileMix
 
                         handler.stream = TextIOWrapper(
                             FileIO(
-                                sys.stderr._original_stdstream_copy,  # type:ignore[attr-defined]
+                                sys.stderr._original_stdstream_copy,
                                 "w",
                             )
                         )
